@@ -2,5 +2,6 @@ from .network import Network
 from .method import Method
 from .client import Client
 from .state import StateManager
-from . import models
-from . import filters
\ No newline at end of file
+from . import enums
+from . import filters
+from . import types
\ No newline at end of file
