@@ -1,11 +1,16 @@
 from typing import Optional, Callable, Literal, Union
-from rubigram.models import Update, InlineMessage
+from rubigram.types import Update, InlineMessage
 from rubigram.method import Method
 from rubigram.filters import Filter
 from rubigram.state import StateManager
 from datetime import datetime
 from aiohttp import web
 import asyncio
+import logging
+
+
+logging.basicConfig(format=("%(levelname)s | %(message)s"))
+
 
 class Client(Method):
     def __init__(
@@ -20,11 +25,13 @@ class Client(Method):
         self.host = host
         self.port = port
         self.offset_id = None
+        self.ROUTES = []
         self.MESSAGE_HANDLER = []
         self.INLINE_HANDLER = []
         self.state = StateManager()
         super().__init__(token)     
             
+
     def create_handler(self, type: Literal["message", "inline"], filters: Optional[Filter] = None):
         def decorator(func: Callable) -> Callable:
             async def wrapper(client: Client, update: Update):
@@ -66,11 +73,9 @@ class Client(Method):
     
     async def on_startup(self, app):
         await self.set_endpoints()
-        await self.state.start()
         await self.start()
 
     async def on_cleanup(self, app):
-        await self.state.stop()
         await self.stop()
         
     def create_request_handler(self):
@@ -82,7 +87,6 @@ class Client(Method):
     
     async def runner(self):
         try:
-            await self.state.start()
             while True:
                 get_updates = await self.get_update(100, self.offset_id)
                 if get_updates.updates:
@@ -95,21 +99,32 @@ class Client(Method):
                             await self.dispatch(update, "message")
                     self.offset_id = get_updates.next_offset_id
         except Exception as error:
-            print(f"ERROR : {error}")
+            logging.error(error)
         finally:
-            await self.state.stop()
             await self.stop()
     
+    def create_app(self, path: str, method: str = "Get"):
+        def decorator(func):
+            self.ROUTES.append((path, func, method))
+            return func
+        return decorator
+            
     def run(self):
         if self.endpoint:
             app = web.Application()
             app.on_startup(self.on_startup)
             app.on_cleanup(self.on_cleanup)
+            for path, func, method in self.ROUTES:
+                if method.upper() == "GET":
+                    app.router.add_get(path, func)
+                elif method.upper() == "POST":
+                    app.router.add_post(path, func)
             app.router.add_post("/ReceiveUpdate", self.create_request_handler())
             app.router.add_post("/ReceiveInlineMessage", self.create_request_handler())
             web.run_app(app, host=self.host, port=self.port)
         else:
             try:
                 asyncio.run(self.runner())
+            except KeyboardInterrupt:pass
             except Exception as error:
-                print(f"ERROR : {error}")
\ No newline at end of file
+                logging.error(error)
\ No newline at end of file
