@@ -1,4 +1,4 @@
-from rubigram.models import Update, InlineMessage
+from rubigram.types import Update, InlineMessage
 from typing import Union
 import re
 
@@ -108,36 +108,45 @@ forward_channel = Filter(FORWARD_CHANNEL)
 
 
 class state(Filter):
-    def __init__(self, states: Union[str, list[str]]):
-        self.states = states
+    def __init__(self, state: Union[str, list[str]]):
+        self.states = state if isinstance(state, list) else [state]
         super().__init__(self.filter)
         
     async def filter(self, update: Union[Update, InlineMessage]):
-        states = self.states if isinstance(self.states, list) else [self.states]
-        user = await update.client.state.get_state(update.chat_id)
-        return user.lower() in states if user else False
+        user_state = await update.client.state.get_state(update.chat_id)
+        return user_state in self.states
             
 
 class command(Filter):
-    def __init__(self, cmd: Union[str, list[str]], prefix: str = "/"):
-        self.cmd = cmd
-        self.prefix = prefix
+    def __init__(self, command: Union[str, list[str]], prefix: Union[str, list[str]] = "/", case_sensitive: bool = False):
+        self.commands = [c if case_sensitive else c.lower() for c in (command if isinstance(command, list) else [command])]
+        self.prefixs = prefix if isinstance(prefix, list) else [prefix]
+        self.cmds = [p + c for p in self.prefixs for c in self.commands]
+        self.case_sensitive = case_sensitive
         super().__init__(self.filter)
 
     async def filter(self, update: Update):
-        commands = self.cmd if isinstance(self.cmd, list) else [self.cmd]
-        text = ""
-        if isinstance(update, Update):
-            if update.type == "NewMessage":
-                text = update.new_message.text
-            elif update.type == "UpdatedMessage":
-                text = update.updated_message.text
-            if text:
-                for cmd in commands:
-                    if text.lower().startswith(self.prefix + cmd.lower()):
-                        return True
-                return False
+        if isinstance(update, Update) and update.type == "NewMessage":
+            text = update.new_message.text or ""
+            text = text if self.case_sensitive else text.lower()
+            return any(text.startswith(cmd) for cmd in self.cmds)
+        return False
+    
 
+class button(Filter):
+    def __init__(self, button_id: Union[str, list[str]], prefix: Union[str, list[str]] = "", case_sensitive: bool = False):
+        self.button_ids = [btn_id if case_sensitive else btn_id.lower() for btn_id in (button_id if isinstance(button_id, list) else [button_id])]
+        self.prefixs = prefix if isinstance(prefix, list) else [prefix]
+        self.btn_ids = [p + b for p in self.prefixs for b in self.button_ids]
+        self.case_sensitive = case_sensitive
+        super().__init__(self.filter)
+
+    async def filter(self, update: InlineMessage):
+        if isinstance(update, InlineMessage):
+            text = update.text or ""
+            text = text if self.case_sensitive else text.lower()
+            return any(text.startswith(btn) for btn in self.btn_ids)
+        return False
 
 class regex(Filter):
     def __init__(self, pattern: str):
@@ -166,19 +175,4 @@ class chat(Filter):
 
     async def filter(self, update: Union[Update, InlineMessage]):
         chat_ids = self.chat_id if isinstance(self.chat_id, list) else [self.chat_id]
-        return update.chat_id in chat_ids
-
-
-class button(Filter):
-    def __init__(self, button_id: Union[str, list[str]], prefix: str = ""):
-        self.button_id = button_id
-        self.prefix = prefix
-        super().__init__(self.filter)
-
-    async def filter(self, update: InlineMessage):
-        if isinstance(update, InlineMessage):
-            button_ids = self.button_id if isinstance(self.button_id, list) else [self.button_id]
-            for btn_id in button_ids:
-                if update.aux_data.button_id.startswith(self.prefix + btn_id):
-                    return True
-            return False
\ No newline at end of file
+        return update.chat_id in chat_ids
\ No newline at end of file
