@@ -1,12 +1,16 @@
 from .network import Network
-from typing import Literal, Optional
-from rubigram.models import Bot, Chat, Keypad, MessageId, Updates
+from . import enums
+from typing import Optional
+from rubigram.types import Bot, Chat, Keypad, MessageId, Updates, BotCommand
 
 
 class Method(Network):
     def __init__(self, token: str):
         super().__init__(token)
-
+        
+    def clean_data(self, data: dict):
+        return {key: value for key, value in data.items() if value is not None}
+        
     async def get_me(self) -> "Bot":
         response = await self.request("getMe", {})
         return Bot.from_dict(response["bot"])
@@ -23,11 +27,11 @@ class Method(Network):
         response = await self.request("getFile", {"file_id": file_id})
         return response["download_url"]
 
-    async def set_command(self, command: list):
-        response = await self.request("setCommands", {"bot_commands": command})
+    async def set_command(self, commands: list[BotCommand]):
+        response = await self.request("setCommands", {"bot_commands": [command.to_dict() for command in commands]})
         return response
 
-    async def update_bot_endpoint(self, url: str, type: Literal["ReceiveUpdate", "ReceiveInlineMessage", "ReceiveQuery", "GetSelectionItem", "SearchSelectionItems"]):
+    async def update_bot_endpoint(self, url: str, type: enums.UpdateEndpointType):
         response = await self.request("updateBotEndpoints", {"url": url, "type": type})
         return response
 
@@ -49,7 +53,10 @@ class Method(Network):
     async def forward_message(self, from_chat_id: str, message_id: str, to_chat_id: str, disable_notification: bool = False) -> "MessageId":
         data = {"from_chat_id": from_chat_id, "message_id": message_id, "to_chat_id": to_chat_id, "disable_notification": disable_notification}
         response = await self.request("forwardMessage", data)
-        return MessageId.from_dict(response)
+        message = MessageId.from_dict(response)
+        message.chat_id = to_chat_id
+        message.client = self
+        return message
 
     async def send_message(
         self,
@@ -57,7 +64,7 @@ class Method(Network):
         text: str,
         chat_keypad: Keypad = None,
         inline_keypad: Keypad = None,
-        chat_keypad_type: Literal["New", "Remove"] = None,
+        chat_keypad_type: Optional[enums.ChatKeypadType] = None,
         disable_notification: bool = None,
         reply_to_message_id=None
     ) -> "MessageId":
@@ -70,9 +77,11 @@ class Method(Network):
             "disable_notification": disable_notification,
             "reply_to_message_id": reply_to_message_id
         }
-        data = {key: value for key, value in data.items() if value is not None}
-        response = await self.request("sendMessage", data)
-        return MessageId.from_dict(response)
+        response = await self.request("sendMessage", self.clean_data(data))
+        message = MessageId.from_dict(response)
+        message.chat_id = chat_id
+        message.client = self
+        return message
 
     async def send_poll(
         self,
@@ -81,9 +90,9 @@ class Method(Network):
         options: list[str],
         chat_keypad: Keypad = None,
         inline_keypad: Keypad = None,
+        chat_keypad_type: Optional[enums.ChatKeypadType] = None,
         disable_notification: bool = False,
         reply_to_message_id: str = None,
-        chat_keypad_type: Literal["New", "Remove"] = None
     ) -> "MessageId":
         data = {
             "chat_id": chat_id,
@@ -95,9 +104,11 @@ class Method(Network):
             "reply_to_message_id": reply_to_message_id,
             "chat_keypad_type": chat_keypad_type
         }
-        data = {key: value for key, value in data.items() if value is not None}
-        response = await self.request("sendPoll", data)
-        return MessageId.from_dict(response)
+        response = await self.request("sendPoll", self.clean_data(data))
+        message = MessageId.from_dict(response)
+        message.chat_id = chat_id
+        message.client = self
+        return message
 
     async def send_location(
         self,
@@ -106,9 +117,9 @@ class Method(Network):
         longitude: str,
         chat_keypad: Keypad = None,
         inline_keypad: Keypad = None,
+        chat_keypad_type: Optional[enums.ChatKeypadType] = None,
         disable_notification: bool = False,
         reply_to_message_id: str = None,
-        chat_keypad_type: Literal["New", "Remove"] = None
     ) -> "MessageId":
         data = {
             "chat_id": chat_id,
@@ -120,9 +131,11 @@ class Method(Network):
             "reply_to_message_id": reply_to_message_id,
             "chat_keypad_type": chat_keypad_type
         }
-        data = {key: value for key, value in data.items() if value is not None}
-        response = await self.request("sendLocation", data)
-        return MessageId.from_dict(response)
+        response = await self.request("sendLocation", self.clean_data(data))
+        message = MessageId.from_dict(response)
+        message.chat_id = chat_id
+        message.client = self
+        return message
 
     async def send_contact(
         self,
@@ -132,9 +145,9 @@ class Method(Network):
         phone_number: str,
         chat_keypad: Keypad = None,
         inline_keypad: Keypad = None,
+        chat_keypad_type: Optional[enums.ChatKeypadType] = None,
         disable_notification: bool = False,
         reply_to_message_id: str = None,
-        chat_keypad_type: Literal["New", "Remove"] = None
     ) -> "MessageId":
         data = {
             "chat_id": chat_id,
@@ -147,9 +160,11 @@ class Method(Network):
             "reply_to_message_id": reply_to_message_id,
             "chat_keypad_type": chat_keypad_type
         }
-        data = {key: value for key, value in data.items() if value is not None}
-        response = await self.request("sendContact", data)
-        return MessageId.from_dict(response)
+        response = await self.request("sendContact", self.clean_data(data))
+        message = MessageId.from_dict(response)
+        message.chat_id = chat_id
+        message.client = self
+        return message
 
     async def send_sticker(
         self,
@@ -157,9 +172,9 @@ class Method(Network):
         sticker_id: str,
         chat_keypad: Keypad = None,
         inline_keypad: Keypad = None,
+        chat_keypad_type: Optional[enums.ChatKeypadType] = None,
         disable_notification: bool = False,
         reply_to_message_id: str = None,
-        chat_keypad_type: Literal["New", "Remove"] = None,
     ) -> "MessageId":
         data = {
             "chat_id": chat_id,
@@ -170,9 +185,11 @@ class Method(Network):
             "reply_to_message_id": reply_to_message_id,
             "chat_keypad_type": chat_keypad_type
         }
-        data = {key: value for key, value in data.items() if value is not None}
-        response = await self.request("sendSticker", data)
-        return MessageId.from_dict(response)
+        response = await self.request("sendSticker", self.clean_data(data))
+        message = MessageId.from_dict(response)
+        message.chat_id = chat_id
+        message.client = self
+        return message
 
     async def request_send_file(self, type: str):
         response = await self.request("requestSendFile", {"type": type})
@@ -194,10 +211,10 @@ class Method(Network):
         file: str,
         file_name: str,
         caption: str = None,
-        type: Literal["File", "Image", "Voice", "Music", "Gif", "Video"] = "File",
+        type: enums.FileType = enums.FileType.File,
         chat_keypad: Keypad = None,
         inline_keypad: Keypad = None,
-        chat_keypad_type: Literal["New", "Remove"] = None,
+        chat_keypad_type: Optional[enums.ChatKeypadType] = None,
         disable_notification: bool = False,
         reply_to_message_id: str = None,
     ) -> "MessageId":
@@ -212,9 +229,12 @@ class Method(Network):
             "reply_to_message_id": reply_to_message_id,
             "chat_keypad_type": chat_keypad_type,
         }
-        data = {key: value for key, value in data.items() if value is not None}
-        response = await self.request("sendFile", data)
-        return MessageId.from_dict(response)
+        response = await self.request("sendFile", self.clean_data(data))
+        message = MessageId.from_dict(response)
+        message.chat_id = chat_id
+        message.file_id = file_id
+        message.client = self
+        return message
 
     async def send_document(self, chat_id: str, document: str, name: str, caption: str = None, **kwargs):
         return await self.send_file(chat_id, document, name, caption, "File", **kwargs)
